@@ -23,14 +23,12 @@ import (
 	"bufio"
 	"encoding/hex"
 	"errors"
-	"fmt"
 	"io"
 	"os"
 	"path"
 	"path/filepath"
 
 	"go.cypherpunks.ru/recfile"
-	"golang.org/x/sys/unix"
 	"lukechampine.com/blake3"
 )
 
@@ -75,15 +73,6 @@ func stamp(fdDep, src *os.File) error {
 	)
 }
 
-func fileCtime(fd *os.File) (string, error) {
-	var stat unix.Stat_t
-	if err := unix.Fstat(int(fd.Fd()), &stat); err != nil {
-		return "", err
-	}
-	sec, nsec := stat.Ctim.Unix()
-	return fmt.Sprintf("%d.%d", sec, nsec), nil
-}
-
 func fileHash(fd *os.File) (string, error) {
 	h := blake3.New(32, nil)
 	if _, err := io.Copy(h, bufio.NewReader(fd)); err != nil {
@@ -106,7 +95,7 @@ func writeDep(fdDep *os.File, cwd, tgt string) error {
 	if fi.IsDir() {
 		return nil
 	}
-	ts, err := fileCtime(fd)
+	inode, err := inodeFromFile(fd)
 	if err != nil {
 		return err
 	}
@@ -114,13 +103,13 @@ func writeDep(fdDep *os.File, cwd, tgt string) error {
 	if err != nil {
 		return err
 	}
-	return recfileWrite(
-		fdDep,
-		recfile.Field{Name: "Type", Value: DepTypeIfchange},
-		recfile.Field{Name: "Target", Value: tgt},
-		recfile.Field{Name: "Ctime", Value: ts},
-		recfile.Field{Name: "Hash", Value: hsh},
-	)
+	fields := []recfile.Field{
+		{Name: "Type", Value: DepTypeIfchange},
+		{Name: "Target", Value: tgt},
+		{Name: "Hash", Value: hsh},
+	}
+	fields = append(fields, inode.RecfileFields()...)
+	return recfileWrite(fdDep, fields...)
 }
 
 func writeDeps(fdDep *os.File, tgts []string) (err error) {
@@ -142,12 +131,13 @@ func writeDeps(fdDep *os.File, tgts []string) (err error) {
 			err = writeDep(fdDep, tgtDir, tgtRel)
 		} else {
 			trace(CDebug, "ifchange: %s <- %s (unexisting)", fdDep.Name(), tgtRel)
-			err = recfileWrite(
-				fdDep,
-				recfile.Field{Name: "Type", Value: DepTypeIfchange},
-				recfile.Field{Name: "Target", Value: tgtRel},
-				recfile.Field{Name: "Ctime", Value: "0.0"},
-			)
+			fields := []recfile.Field{
+				{Name: "Type", Value: DepTypeIfchange},
+				{Name: "Target", Value: tgtRel},
+			}
+			inodeDummy := Inode{}
+			fields = append(fields, inodeDummy.RecfileFields()...)
+			err = recfileWrite(fdDep, fields...)
 		}
 	}
 	return
