@@ -28,7 +28,6 @@ import (
 	"path"
 	"path/filepath"
 	"strconv"
-	"strings"
 
 	"go.cypherpunks.ru/recfile"
 )
@@ -102,6 +101,7 @@ func main() {
 
 	NoColor = os.Getenv(EnvNoColor) != ""
 	NoSync = os.Getenv(EnvNoSync) == "1"
+	InodeTrust = os.Getenv(EnvInodeNoTrust) == ""
 
 	TopDir = os.Getenv(EnvTopDir)
 	if TopDir == "" {
@@ -270,7 +270,6 @@ CmdSwitch:
 		}
 		os.Remove(fdTmp.Name())
 		cwd, tgt := cwdAndTgt(tgts[0])
-		cwdRel := cwdMustRel(cwd)
 		doFile, upLevels, err := findDo(fdTmp, cwd, tgt)
 		if err != nil {
 			break
@@ -293,7 +292,17 @@ CmdSwitch:
 		if doFile == "" {
 			ok = false
 		} else {
-			fmt.Println(path.Join(cwdRel, strings.Repeat("..", upLevels), doFile))
+			p := make([]string, 0, upLevels+2)
+			p = append(p, cwd)
+			for i := 0; i < upLevels; i++ {
+				p = append(p, "..")
+			}
+			p = append(p, doFile)
+			rel, err := filepath.Rel(Cwd, path.Join(p...))
+			if err != nil {
+				panic(err)
+			}
+			fmt.Println(rel)
 		}
 	default:
 		log.Fatalln("unknown command", cmdName)
