@@ -101,24 +101,24 @@ func mkdirs(pth string) error {
 	return os.MkdirAll(pth, os.FileMode(0777))
 }
 
-func isModified(cwd, redoDir, tgt string) (bool, string, error) {
+func isModified(cwd, redoDir, tgt string) (bool, *Inode, error) {
 	fdDep, err := os.Open(path.Join(redoDir, tgt+DepSuffix))
 	if err != nil {
 		if os.IsNotExist(err) {
-			return false, "", nil
+			return false, nil, nil
 		}
-		return false, "", err
+		return false, nil, err
 	}
 	defer fdDep.Close()
 	r := recfile.NewReader(fdDep)
-	var ourTs string
+	var ourInode *Inode
 	for {
 		m, err := r.NextMap()
 		if err != nil {
 			if err == io.EOF {
 				break
 			}
-			return false, "", err
+			return false, nil, err
 		}
 		if m["Target"] != tgt {
 			continue
@@ -126,21 +126,25 @@ func isModified(cwd, redoDir, tgt string) (bool, string, error) {
 		fd, err := os.Open(path.Join(cwd, tgt))
 		if err != nil {
 			if os.IsNotExist(err) {
-				return false, "", nil
+				return false, nil, nil
 			}
-			return false, "", err
+			return false, nil, err
 		}
-		defer fd.Close()
-		ourTs, err = fileCtime(fd)
+		ourInode, err = inodeFromFile(fd)
+		fd.Close()
 		if err != nil {
-			return false, "", err
+			return false, nil, err
 		}
-		if ourTs != m["Ctime"] {
-			return true, ourTs, nil
+		theirInode, err := inodeFromRec(m)
+		if err != nil {
+			return false, nil, err
+		}
+		if !ourInode.Equals(theirInode) {
+			return true, ourInode, nil
 		}
 		break
 	}
-	return false, ourTs, nil
+	return false, ourInode, nil
 }
 
 func syncDir(dir string) error {
@@ -222,7 +226,7 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 	}
 
 	// Check if target is not modified externally
-	modified, tsPrev, err := isModified(cwd, redoDir, tgt)
+	modified, inodePrev, err := isModified(cwd, redoDir, tgt)
 	if err != nil {
 		lockRelease()
 		return TgtErr{tgtOrig, err}
@@ -462,11 +466,11 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		}
 
 		// Was $1 touched?
-		if tsPrev != "" {
+		if inodePrev != nil {
 			if fd, err := os.Open(path.Join(cwdOrig, tgt)); err == nil {
-				ts, err := fileCtime(fd)
+				inode, err := inodeFromFile(fd)
 				fd.Close()
-				if err == nil && ts != tsPrev {
+				if err == nil && !inode.Equals(inodePrev) {
 					runErr.Err = errors.New("$1 was explicitly touched")
 					errs <- runErr
 					fd.Close()
