@@ -26,7 +26,7 @@ import (
 )
 
 const (
-	Version  = "0.12.3"
+	Version  = "1.0.0"
 	Warranty = `This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, version 3 of the License.
@@ -91,5 +91,7 @@ Additional environment variables:
   NO_COLOR -- disable messages colouring
   REDO_NO_SYNC -- disable files/directories explicit filesystem syncing
   REDO_TOP_DIR -- do not search for .do above that directory
-                  (it can contain .redo/top as an alternative)`)
+                  (it can contain .redo/top as an alternative)
+  REDO_INODE_NO_TRUST -- do not trust inode information (except for size)
+                         and always check file's hash`)
 }
